/*!
 * Fast "async" scrypt implementation in modern JavaScript.
 * Copyright (c) 2019 Charles Crete | MIT License
 * https://github.com/Cretezy/scrypt-async-modern
 */
export interface IScryptOptions {
    N?: number;
    logN?: number;
    r?: number;
    p?: number;
    dkLen?: number;
    interruptStep?: number;
    encoding?: "base64" | "hex" | "binary";
}
/**
 * scrypt(password, salt, options): Promise
 *
 * where
 *
 * password and salt are strings or arrays of bytes (Array of Uint8Array)
 * options is
 *
 * {
 *    N:             // CPU/memory cost parameter, must be power of two,
 *                   // default = 16384
 *                   // (alternatively, you can specify logN)
 *    r:             // block size, default = 8
 *    p:             // parallelization parameter, default = 1
 *    dkLen:         // length of derived key, default = 32
 *    encoding:      // optional encoding:
 *                      "base64" - standard Base64 encoding
 *                      "hex" — hex encoding,
 *                      "binary" — Uint8Array,
 *                      undefined/null - Array of bytes (default)
 *    interruptStep: // optional, steps to split calculations, default = 0
 * }
 *
 * Derives a key from password and salt and fulfills Promise
 * with derived key as the only argument.
 *
 * Calculations are interrupted with setImmediate (or zero setTimeout) at the
 * given interruptSteps to avoid freezing the browser. If it's undefined or zero,
 * the callback is called immediately after the calculation, avoiding setImmediate.
 *
 */
export default function scrypt(password: any, salt: any, { N, logN, r, p, dkLen, interruptStep, encoding }?: IScryptOptions): Promise<unknown>;
